==> AGXUnreal-1.17.0_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Toughness/CylindricalThresholdFracture.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Toughness/DefaultCylindricalToughness.h>
#include <openplx/Physics/Interactions/Toughness/ThresholdFracture.h>
/* Generated code for model CylindricalThresholdFracture */
namespace openplx::Physics3D::Interactions::Toughness {
    /**
     *     Define a threshold fracture model for each constrained degree of freedom for a Cylindrical.
     *     Each dimension can then fail individually at their fracture points.
     *     */
    class CylindricalThresholdFracture : public openplx::Physics3D::Interactions::Toughness::DefaultCylindricalToughness {
        protected:
            double m_default_limit;

        public:
            CylindricalThresholdFracture();
            double default_limit() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.5_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Interactions/Toughness/CylindricalThresholdFracture.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics3D/Interactions/Toughness/DefaultCylindricalToughness.h>
#include <openplx/Physics/Interactions/Toughness/ThresholdFracture.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model CylindricalThresholdFracture */
namespace openplx::Physics3D::Interactions::Toughness {
    /**
     *     Define a threshold fracture model for each constrained degree of freedom for a Cylindrical.
     *     Each dimension can then fail individually at their fracture points.
     *     */
    class OPENPLX_Physics3D_BUNDLE_EXPORT CylindricalThresholdFracture : public openplx::Physics3D::Interactions::Toughness::DefaultCylindricalToughness {
        protected:
            double m_default_limit;

        public:
            CylindricalThresholdFracture();
            virtual ~CylindricalThresholdFracture();
            double default_limit() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> along_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> along_cross() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> around_normal() const;
            std::shared_ptr<openplx::Physics::Interactions::Toughness::ThresholdFracture> around_cross() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
